..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Objectives
----------

-  To understand why algorithm analysis is important.

-  To be able to use Big O to describe execution time.

-  To understand the Big O execution time of common operations on
   Python lists and dictionaries.

-  To understand how the implementation of Python data impacts algorithm
   analysis.

-  To understand how to benchmark simple Python programs.

